# Speedcord 
###  A simple discord API wrapper made to be easily hacked.

![GitHub last commit](https://img.shields.io/github/last-commit/tag-epic/speedcord)
![GitHub issues](https://img.shields.io/github/issues-raw/tag-epic/speedcord)
![GitHub pull requests](https://img.shields.io/github/issues-pr/tag-epic/speedcord)
![PyPI downloads](https://img.shields.io/pypi/dm/speedcord)
[![Discord support](https://img.shields.io/discord/784592146182570015)](https://discord.gg/QTX36dDMzT)
[![GitHub license](https://img.shields.io/github/license/TAG-Epic/speedcord)](https://github.com/TAG-Epic/speedcord/blob/master/LICENCE) 


### DEPRECATION NOTICE
Speedcord is being superseded by https://github.com/nextsnake/nextcore


## Installing
You can install Speedcord from PyPi using the following command:

```bash
pip3 install speedcord
```
It is recommended to **pin the version in production as breaking changes might occur**


## Features
 - Simple sharding for larger bots
 - Speedier requests to the discord API
 - More customizablility


## Usage
There are currently few examples, you are free to contribute new examples

- [Simple command using the `MESSAGE_CREATE` listener](https://github.com/TAG-Epic/speedcord/blob/master/examples/simplecommand.py)

### Extended usage
Using extensions can make your speedcord development experience much more pleasant. Here's a list of extensions which might help you  
[Speedian - interactions handler](https://github.com/tag-epic/speedcord-command-handler)

## Contributing

Contributions are more than welcome as long as they follow our [contribution guidelines](https://github.com/TAG-Epic/speedcord/blob/master/CONTRIBUTING.md)
